/*
   ----------------------------------------------------------------------------
   MyReportControls.cc
   Sample code from The dBASE Reports Book, second edition
   ReportControls folder, from Chapter 4
   Copyright  2016, Kenneth J. Mayer
   
   This is a custom class file designed to store custom classes used
   by the various reports in the book.
   
   This may be used for other purposes, as needed. 
   ----------------------------------------------------------------------------
*/
class MAINTITLETEXT(parentObj) of TEXT(parentObj) custom
   with (this)
      metric = 3	// Inches
      height = 0.3646
      width = 3.0833
      prefixEnable = false
      alignHorizontal = 1	// Center
      fontSize = 20.0
      fontItalic = true
      //fontName = "Calligraphic"
      text = "My Company Name"
   endwith
endclass

class SECONDARYTITLETEXT(parentObj) of TEXT(parentObj) custom
   with (this)
      height = 0.2708
      width = 2.3333
      metric = 3	// Inches
      prefixEnable = false
      alignHorizontal = 1	// Center
      fontSize = 16.0
      text = "Purpose of Report"
   endwith
endclass

class DATETEXT(parentObj) of TEXT(parentObj) custom
   with (this)
      height = 0.2083
      width = 2.1042
      metric = 3	// Inches
      prefixEnable = false
      alignHorizontal = 1	// Center
      fontSize = 12.0
      text = {||cmonth(date())+" "+day(date())+", "+year(date())}
   endwith

endclass

class DATATEXT(parentObj) of TEXT(parentObj) custom
   with (this)
      fontName = "Arial"
      fontSize = 10
      text = "DataText"
   endwith
endclass

class DATAHEADINGTEXT(parentObj) of DATATEXT(parentObj) custom
   with (this)
      fontBold = true
      text = "DataHeadingText"
   endwith
endclass

class DATACOLHEADINGTEXT(parentObj) of DATAHEADINGTEXT(parentObj) custom
   with( this )
      text = "ColumnHeadingText"
      suppressIfBlank = true
      canRender = {||this.parent.firstOnFrame}
   endwith
endclass

class PageNum( parentObj ) of DataText( parentObj ) custom
   // Class that outputs "Page n" where "n" is the current
   // page number - the value of the report's reportPage
   // property:
   with( this )
      fontSize = 8
      text = class::PageValue
   endwith
   
   function PageValue
      local cPage
      cPage = "Page "
      if type( "this.form.reportPage" ) == "N"
         // add page number to end of text
         cPage += this.form.reportPage
      else
         // if this is not used on a report,
         // return word "ERROR"
         cPage := "ERROR"
      endif
   return( cPage )
endclass

class PageNumOffset( parentObj ) of DataText( parentObj ) custom
   // Page Number Offset class, this offsets the report's
   // reportPage property by some number, so that the first
   // page of the report will be form.reportPage+offsetvalue
   // When using this class, place it on a report, and then
   // in the text control's onOpen event, enter:
   // {; this.pageOffset := 2 }
   // where "2" is the amount you wish to add to the
   // reportPage value to offset the page number.
   with( this )
      fontSize = 8
      text = class::PageValue
   endwith
   this.pageOffset = 0 // default to zero
   
   function PageValue
      local nPage
      nPage = 0
      if type( "this.form.reportPage" ) == "N"
         // add page number to end of text
         nPage := this.form.reportPage + this.pageOffset
      else
         // if this is not used on a report,
         // return zero
         nPage := 0
      endif
   return( nPage )
endclass
